@@ -1,10 +1,9 @@
-.onLoad<- function(lib, pkg, ...)
-{
-    packageStartupMessage(chainladderWelcomeMessage())
 
-    invisible()
+.onAttach <- function(lib, pkg,...){
+  packageStartupMessage(chainladderWelcomeMessage())
 }
 
+
 chainladderWelcomeMessage <- function(){
 
   paste("\nChainLadder version ", packageDescription("ChainLadder")$Version,
